@@ -43,16 +43,7 @@ from sqlalchemy import (
 from sqlalchemy.orm import Mapped, backref, declared_attr, relationship
 
 from airflow.api_fastapi.auth.managers.models.base_user import BaseUser
-
-try:
-    from sqlalchemy.orm import mapped_column
-except ImportError:
-    # fallback for SQLAlchemy < 2.0
-    def mapped_column(*args, **kwargs):
-        from sqlalchemy import Column
-
-        return Column(*args, **kwargs)
-
+from airflow.providers.common.compat.sqlalchemy.orm import mapped_column
 
 if TYPE_CHECKING:
     try:
@@ -225,9 +216,9 @@ class Group(Model):
         Sequence("ab_group_id_seq", start=1, increment=1, minvalue=1, cycle=False),
         primary_key=True,
     )
-    name: Mapped[str] = Column(String(100), unique=True, nullable=False)
-    label: Mapped[str] = Column(String(150))
-    description: Mapped[str] = Column(String(512))
+    name: Mapped[str] = mapped_column(String(100), unique=True, nullable=False)
+    label: Mapped[str | None] = mapped_column(String(150))
+    description: Mapped[str | None] = mapped_column(String(512))
     users: Mapped[list[User]] = relationship(
         "User", secondary=assoc_user_group, backref="groups", passive_deletes=True
     )
