@@ -23,12 +23,12 @@ from unittest import mock
 from unittest.mock import MagicMock, Mock
 
 import pytest
-from flask import Flask, g
+from flask import g
 
-from airflow.api_fastapi.app import AUTH_MANAGER_FASTAPI_APP_PREFIX
+from airflow.api_fastapi.app import AUTH_MANAGER_FASTAPI_APP_PREFIX, get_auth_manager
 from airflow.api_fastapi.common.types import MenuItem
 from airflow.exceptions import AirflowConfigException
-from airflow.providers.fab.www.extensions.init_appbuilder import init_appbuilder
+from airflow.providers.fab.www.app import create_app
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.utils.db import resetdb
 
@@ -42,17 +42,13 @@ with suppress(ImportError):
         DagDetails,
     )
 
-from tests_common.test_utils.compat import ignore_provider_compatibility_error
-
-with ignore_provider_compatibility_error("2.9.0+", __file__):
-    from airflow.providers.fab.auth_manager.fab_auth_manager import FabAuthManager
-    from airflow.providers.fab.auth_manager.security_manager.override import FabAirflowSecurityManagerOverride
-
 from airflow.providers.common.compat.security.permissions import (
     RESOURCE_ASSET,
     RESOURCE_ASSET_ALIAS,
     RESOURCE_BACKFILL,
 )
+from airflow.providers.fab.auth_manager.fab_auth_manager import FabAuthManager
+from airflow.providers.fab.auth_manager.security_manager.override import FabAirflowSecurityManagerOverride
 from airflow.providers.fab.www.security.permissions import (
     ACTION_CAN_ACCESS_MENU,
     ACTION_CAN_CREATE,
@@ -74,6 +70,7 @@ from airflow.providers.fab.www.security.permissions import (
     RESOURCE_WEBSITE,
 )
 
+from tests_common.test_utils.dag import sync_dag_to_db
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_1_PLUS
 
 if AIRFLOW_V_3_1_PLUS:
@@ -166,17 +163,14 @@ def flask_app():
             ): "airflow.providers.fab.auth_manager.fab_auth_manager.FabAuthManager",
         }
     ):
-        yield Flask(__name__)
+        app = create_app(enable_plugins=False)
+        with app.app_context():
+            yield app
 
 
 @pytest.fixture
 def auth_manager_with_appbuilder(flask_app):
-    flask_app.config["AUTH_RATE_LIMITED"] = False
-    flask_app.config["SERVER_NAME"] = "localhost"
-    appbuilder = init_appbuilder(flask_app, enable_plugins=False)
-    auth_manager = FabAuthManager()
-    auth_manager.appbuilder = appbuilder
-    return auth_manager
+    return get_auth_manager()
 
 
 @pytest.mark.db_test
@@ -204,7 +198,7 @@ class TestFabAuthManager:
     def test_deserialize_user(self, flask_app, auth_manager_with_appbuilder):
         user = create_user(flask_app, "test")
         result = auth_manager_with_appbuilder.deserialize_user({"sub": str(user.id)})
-        assert user == result
+        assert user.get_id() == result.get_id()
 
     def test_serialize_user(self, flask_app, auth_manager_with_appbuilder):
         user = create_user(flask_app, "test")
@@ -294,6 +288,95 @@ class TestFabAuthManager:
                 [(ACTION_CAN_READ, RESOURCE_DAG)],
                 True,
             ),
+            # Without permission on DAGs
+            (
+                "GET",
+                None,
+                None,
+                [(ACTION_CAN_READ, "resource_test")],
+                False,
+            ),
+            # With specific DAG permissions but no specific DAG requested
+            (
+                "GET",
+                None,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id")],
+                True,
+            ),
+            # With multiple specific DAG permissions, no specific DAG requested
+            (
+                "GET",
+                None,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, "DAG:test_dag_id2")],
+                True,
+            ),
+            # With specific DAG permissions and wrong method
+            (
+                "POST",
+                None,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id")],
+                False,
+            ),
+            # With correct POST permissions
+            (
+                "POST",
+                None,
+                None,
+                [(ACTION_CAN_CREATE, RESOURCE_DAG)],
+                True,
+            ),
+            # Mixed permissions - some DAG, some non-DAG
+            (
+                "GET",
+                None,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, "resource_test")],
+                True,
+            ),
+            # DAG sub-entity with specific DAG permissions but no specific DAG requested
+            (
+                "GET",
+                DagAccessEntity.RUN,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, RESOURCE_DAG_RUN)],
+                True,
+            ),
+            # DAG sub-entity access with no DAG permissions, no specific DAG requested
+            (
+                "GET",
+                DagAccessEntity.RUN,
+                None,
+                [(ACTION_CAN_READ, RESOURCE_DAG_RUN)],
+                False,
+            ),
+            # DAG sub-entity with specific DAG permissions but missing sub-entity permission
+            (
+                "GET",
+                DagAccessEntity.TASK_INSTANCE,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id")],
+                False,
+            ),
+            # Multiple DAG access entities with proper permissions
+            (
+                "DELETE",
+                DagAccessEntity.TASK,
+                None,
+                [(ACTION_CAN_EDIT, "DAG:test_dag_id"), (ACTION_CAN_DELETE, RESOURCE_TASK_INSTANCE)],
+                True,
+            ),
+            # User with specific DAG permissions but wrong method for sub-entity
+            (
+                "POST",
+                DagAccessEntity.RUN,
+                None,
+                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, RESOURCE_DAG_RUN)],
+                False,
+            ),
+            # Scenario 2 #
             # On specific DAG with global permissions on Dags
             (
                 "GET",
@@ -326,71 +409,7 @@ class TestFabAuthManager:
                 [(ACTION_CAN_READ, "DAG:test_dag_id")],
                 False,
             ),
-            # Without permission on DAGs
-            (
-                "GET",
-                None,
-                None,
-                [(ACTION_CAN_READ, "resource_test")],
-                False,
-            ),
-            # With specific DAG permissions but no specific DAG requested
-            (
-                "GET",
-                None,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id")],
-                True,
-            ),
-            # With multiple specific DAG permissions, no specific DAG requested
-            (
-                "GET",
-                None,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, "DAG:test_dag_id2")],
-                True,
-            ),
-            # With specific DAG permissions but wrong method
-            (
-                "POST",
-                None,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id")],
-                True,
-            ),
-            # With correct method permissions for specific DAG
-            (
-                "POST",
-                None,
-                None,
-                [(ACTION_CAN_CREATE, "DAG:test_dag_id")],
-                True,
-            ),
-            # With EDIT permission on specific DAG, no specific DAG requested
-            (
-                "PUT",
-                None,
-                None,
-                [(ACTION_CAN_EDIT, "DAG:test_dag_id")],
-                True,
-            ),
-            # With DELETE permission on specific DAG, no specific DAG requested
-            (
-                "DELETE",
-                None,
-                None,
-                [(ACTION_CAN_DELETE, "DAG:test_dag_id")],
-                True,
-            ),
-            # Mixed permissions - some DAG, some non-DAG
-            (
-                "GET",
-                None,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, "resource_test")],
-                True,
-            ),
-            # Scenario 2 #
+            # Scenario 3 #
             # With global permissions on DAGs
             (
                 "GET",
@@ -415,7 +434,7 @@ class TestFabAuthManager:
                 [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, RESOURCE_TASK_INSTANCE)],
                 False,
             ),
-            # With read permissions on a specific DAG but not on the DAG run
+            # With read permissions on a specific DAG and on the DAG run
             (
                 "GET",
                 DagAccessEntity.TASK_INSTANCE,
@@ -427,7 +446,7 @@ class TestFabAuthManager:
                 ],
                 True,
             ),
-            # With edit permissions on a specific DAG and read on the DAG access entity
+            # With edit permissions on a specific DAG and delete on the DAG access entity
             (
                 "DELETE",
                 DagAccessEntity.TASK,
@@ -435,7 +454,7 @@ class TestFabAuthManager:
                 [(ACTION_CAN_EDIT, "DAG:test_dag_id"), (ACTION_CAN_DELETE, RESOURCE_TASK_INSTANCE)],
                 True,
             ),
-            # With edit permissions on a specific DAG and read on the DAG access entity
+            # With edit permissions on a specific DAG and create on the DAG access entity
             (
                 "POST",
                 DagAccessEntity.RUN,
@@ -459,52 +478,18 @@ class TestFabAuthManager:
                 [(ACTION_CAN_READ, RESOURCE_TASK_INSTANCE)],
                 False,
             ),
-            # DAG sub-entity with specific DAG permissions but no specific DAG requested
+            # Use deprecated prefix "DAG Run" to assign permissions specifically on dag runs
             (
                 "GET",
                 DagAccessEntity.RUN,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, RESOURCE_DAG_RUN)],
-                True,
-            ),
-            # DAG sub-entity access with no DAG permissions, no specific DAG requested
-            (
-                "GET",
-                DagAccessEntity.RUN,
-                None,
-                [(ACTION_CAN_READ, RESOURCE_DAG_RUN)],
-                True,
-            ),
-            # DAG sub-entity with specific DAG permissions but missing sub-entity permission
-            (
-                "GET",
-                DagAccessEntity.TASK_INSTANCE,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id")],
-                False,
-            ),
-            # Multiple DAG access entities with proper permissions
-            (
-                "DELETE",
-                DagAccessEntity.TASK,
-                None,
-                [(ACTION_CAN_EDIT, "DAG:test_dag_id"), (ACTION_CAN_DELETE, RESOURCE_TASK_INSTANCE)],
-                True,
-            ),
-            # User with specific DAG permissions but wrong method for sub-entity
-            (
-                "POST",
-                DagAccessEntity.RUN,
-                None,
-                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, RESOURCE_DAG_RUN)],
+                DagDetails(id="test_dag_id"),
+                [(ACTION_CAN_READ, "DAG:test_dag_id"), (ACTION_CAN_READ, "DAG Run:test_dag_id")],
                 True,
             ),
         ],
     )
-    @mock.patch.object(FabAuthManager, "get_authorized_dag_ids")
     def test_is_authorized_dag(
         self,
-        mock_get_authorized_dag_ids,
         method,
         dag_access_entity,
         dag_details,
@@ -512,10 +497,6 @@ class TestFabAuthManager:
         expected_result,
         auth_manager_with_appbuilder,
     ):
-        dag_permissions = [perm[1] for perm in user_permissions if perm[1].startswith("DAG:")]
-        dag_ids = {perm.replace("DAG:", "") for perm in dag_permissions}
-        mock_get_authorized_dag_ids.return_value = dag_ids
-
         user = Mock()
         user.perms = user_permissions
         user.id = 1
@@ -698,6 +679,12 @@ class TestFabAuthManager:
         result = auth_manager.filter_authorized_menu_items(menu_items, user=user)
         assert result == expected_result
 
+    def test_get_authorized_connections(self, auth_manager):
+        session = Mock()
+        session.execute.return_value.scalars.return_value.all.return_value = ["conn1", "conn2"]
+        result = auth_manager.get_authorized_connections(user=Mock(), method="GET", session=session)
+        assert result == {"conn1", "conn2"}
+
     @pytest.mark.parametrize(
         "method, user_permissions, expected_results",
         [
@@ -706,14 +693,14 @@ class TestFabAuthManager:
             (
                 "GET",
                 [(ACTION_CAN_READ, RESOURCE_DAG)],
-                {"test_dag1", "test_dag2"},
+                {"test_dag1", "test_dag2", "Connections"},
             ),
             # Scenario 2
             # With global edit permissions on Dags
             (
                 "PUT",
                 [(ACTION_CAN_EDIT, RESOURCE_DAG)],
-                {"test_dag1", "test_dag2"},
+                {"test_dag1", "test_dag2", "Connections"},
             ),
             # Scenario 3
             # With DAG-specific permissions
@@ -750,18 +737,32 @@ class TestFabAuthManager:
                 [(ACTION_CAN_EDIT, "DAG:test_dag1"), (ACTION_CAN_EDIT, "DAG:test_dag2")],
                 {"test_dag1", "test_dag2"},
             ),
+            # Scenario 9
+            # With non-DAG related permissions
+            (
+                "GET",
+                [(ACTION_CAN_READ, "DAG:test_dag1"), (ACTION_CAN_READ, RESOURCE_CONNECTION)],
+                {"test_dag1"},
+            ),
         ],
     )
     def test_get_authorized_dag_ids(
-        self, method, user_permissions, expected_results, auth_manager_with_appbuilder, dag_maker, flask_app
+        self, method, user_permissions, expected_results, auth_manager_with_appbuilder, flask_app, dag_maker
     ):
         with dag_maker("test_dag1"):
             EmptyOperator(task_id="task1")
+        if AIRFLOW_V_3_1_PLUS:
+            sync_dag_to_db(dag_maker.dag)
         with dag_maker("test_dag2"):
-            EmptyOperator(task_id="task1")
-
-        auth_manager_with_appbuilder.security_manager.sync_perm_for_dag("test_dag1")
-        auth_manager_with_appbuilder.security_manager.sync_perm_for_dag("test_dag2")
+            EmptyOperator(task_id="task2")
+        if AIRFLOW_V_3_1_PLUS:
+            sync_dag_to_db(dag_maker.dag)
+        with dag_maker("Connections"):
+            EmptyOperator(task_id="task3")
+        if AIRFLOW_V_3_1_PLUS:
+            sync_dag_to_db(dag_maker.dag)
+        dag_maker.session.commit()
+        dag_maker.session.close()
 
         user = create_user(
             flask_app,
@@ -770,11 +771,26 @@ class TestFabAuthManager:
             permissions=user_permissions,
         )
 
+        auth_manager_with_appbuilder.security_manager.sync_perm_for_dag("test_dag1")
+        auth_manager_with_appbuilder.security_manager.sync_perm_for_dag("test_dag2")
+
         results = auth_manager_with_appbuilder.get_authorized_dag_ids(user=user, method=method)
         assert results == expected_results
 
         delete_user(flask_app, "username")
 
+    def test_get_authorized_pools(self, auth_manager):
+        session = Mock()
+        session.execute.return_value.scalars.return_value.all.return_value = ["pool1", "pool2"]
+        result = auth_manager.get_authorized_pools(user=Mock(), method="GET", session=session)
+        assert result == {"pool1", "pool2"}
+
+    def test_get_authorized_variables(self, auth_manager):
+        session = Mock()
+        session.execute.return_value.scalars.return_value.all.return_value = ["var1", "var2"]
+        result = auth_manager.get_authorized_variables(user=Mock(), method="GET", session=session)
+        assert result == {"var1", "var2"}
+
     def test_security_manager_return_fab_security_manager_override(self, auth_manager_with_appbuilder):
         assert isinstance(auth_manager_with_appbuilder.security_manager, FabAirflowSecurityManagerOverride)
 
@@ -783,6 +799,8 @@ class TestFabAuthManager:
             pass
 
         flask_app.config["SECURITY_MANAGER_CLASS"] = TestSecurityManager
+        # Invalidate the cache
+        del auth_manager_with_appbuilder.__dict__["security_manager"]
         assert isinstance(auth_manager_with_appbuilder.security_manager, TestSecurityManager)
 
     def test_security_manager_wrong_inheritance_raise_exception(
@@ -792,7 +810,8 @@ class TestFabAuthManager:
             pass
 
         flask_app.config["SECURITY_MANAGER_CLASS"] = TestSecurityManager
-
+        # Invalidate the cache
+        del auth_manager_with_appbuilder.__dict__["security_manager"]
         with pytest.raises(
             AirflowConfigException,
             match="Your CUSTOM_SECURITY_MANAGER must extend FabAirflowSecurityManagerOverride.",
@@ -809,7 +828,6 @@ class TestFabAuthManager:
 
     @mock.patch.object(FabAuthManager, "_is_authorized", return_value=True)
     def test_get_extra_menu_items(self, _, auth_manager_with_appbuilder, flask_app):
-        auth_manager_with_appbuilder.register_views()
         result = auth_manager_with_appbuilder.get_extra_menu_items(user=Mock())
         assert len(result) == 5
         assert all(item.href.startswith(AUTH_MANAGER_FASTAPI_APP_PREFIX) for item in result)
